@@ -1,9 +1,11 @@
 """Global config"""
 
+import os
+
 
 class Config:
-    MONGO_URI = None
-    DATABASE_NAME = None
+    MONGO_URI = os.environ.get("MONGO_URI", None)
+    DATABASE_NAME = os.environ.get("DATABASE_NAME", None)
 
 
 def update_config(mongo_uri: str, database_name: str):
